@@ -2367,3 +2367,8 @@ close.ncdf <- function( con, ... ) {
 #att.put.ncdf( ncidnew, 0, "title", "This is a test TITLE global attribute")
 #
 #close.ncdf(ncidnew)
+
+.onAttach <- function(libname, pkgname)
+{
+    packageStartupMessage("Package 'ncdf' is deprecated and will be removed from CRAN shortly.", "\n", "Use instead package RNetCDF or ncdf4 (for Windows from CRANextras)")
+}
